# LaTeX Translator

This package is a LaTeX translator that allows you to convert LaTeX code into plain text TXT format.

## Installation

To install this package, simply run the following command:

    $ pip install latextranslator

## Usage

You can review the full list of commands by running `latextranslator --help`.
